pub trait Reducer<Result> {
// Required method
fn reduce(self, left: Result, right: Result) -> Result;
}Expand description
The reducer is the final step of a Consumer – after a consumer
has been split into two parts, and each of those parts has been
fully processed, we are left with two results. The reducer is then
used to combine those two results into one. See the plumbing
README for further details.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".